@@ -190,30 +190,174 @@ class Chrome(Windows, Terminal):
         return elemento
     
     def click_elemento(self, metodo_busqueda:By|str, texto_busqueda:str) -> bool:
-        """ Clickea el elemento """
+        """ Clickea el elemento con múltiples estrategias de reintento """
+        return self._click_elemento_con_reintentos(metodo_busqueda, texto_busqueda)
+    
+    def _click_elemento_con_reintentos(self, metodo_busqueda:By|str, texto_busqueda:str, max_intentos:int=3) -> bool:
+        """ 
+        Clickea el elemento usando múltiples estrategias de reintento
+        Estrategias:
+        1. Click directo en elemento HTML (ideal para VMs e iframes)
+        2. JavaScript click 
+        3. ActionChains click
+        """
+        
+        if not self._driver:
+            raise ValueError("El navegador no está abierto. Por favor, abre el navegador antes de hacer click en un elemento.")
+        
         elemento = self.esperar_elemento_clickeable(metodo_busqueda, texto_busqueda)
         if not elemento: return False
         
+        for intento in range(max_intentos):
+            try:
+                if intento == 0:
+                    # Estrategia 1: Click directo en elemento HTML
+                    self.mostrar(f"🔍 Intento {intento + 1}: Click directo en elemento")
+                    self.__desplazar_elemento_a_vista(elemento)
+                    elemento.click()
+                    self.mostrar(f"✅ Click exitoso en elemento {texto_busqueda}")
+                    return True
+                    
+                elif intento == 1:
+                    # Estrategia 2: JavaScript click (ideal para elementos interceptados)
+                    self.mostrar(f"🔍 Intento {intento + 1}: JavaScript click")
+                    self._driver.execute_script("arguments[0].click();", elemento)
+                    self.mostrar(f"✅ JavaScript click exitoso en elemento {texto_busqueda}")
+                    return True
+                    
+                elif intento == 2:
+                    # Estrategia 3: ActionChains click (para elementos complejos)
+                    self.mostrar(f"🔍 Intento {intento + 1}: ActionChains click")
+                    from selenium.webdriver.common.action_chains import ActionChains
+                    actions = ActionChains(self._driver)
+                    actions.move_to_element(elemento).click().perform()
+                    self.mostrar(f"✅ ActionChains click exitoso en elemento {texto_busqueda}")
+                    return True
+                    
+            except ElementClickInterceptedException as e:
+                self.mostrar(f"❌ Intento {intento + 1}: Elemento {texto_busqueda} está siendo interceptado", True)
+                if intento < max_intentos - 1:
+                    self.mostrar(f"🔄 Reintentando con estrategia alternativa...")
+                    self.demora()
+                continue
+                
+            except Exception as e:
+                self.mostrar(f"❌ Intento {intento + 1}: Error al hacer click en {texto_busqueda}: {str(e)}", True)
+                if intento < max_intentos - 1:
+                    self.mostrar(f"🔄 Reintentando con estrategia alternativa...")
+                    self.demora()
+                continue
+        
+        # Si todas las estrategias fallan, tomar screenshot para debugging
         try:
-            self.__desplazar_elemento_a_vista(elemento)
-            elemento.click()
-            return True
-        except ElementClickInterceptedException:
-            self.mostrar(f"El elemento {texto_busqueda} está siendo interceptado.")
-            return False
+            # Limpiar el texto_busqueda para usar como nombre de archivo
+            texto_limpio = texto_busqueda.replace('/', '_').replace('\\', '_').replace(':', '_').replace('*', '_').replace('?', '_').replace('"', '_').replace('<', '_').replace('>', '_').replace('|', '_')
+            nombre_screenshot = f"error_click_{texto_limpio}"
+            self.tomar_screenshot(nombre_screenshot)
+        except Exception as e:
+            self.mostrar(f"❌ Error al tomar screenshot: {str(e)}", True)
+        
+        self.mostrar(f"❌ No se pudo hacer click en elemento {texto_busqueda} después de {max_intentos} intentos", True)
+        return False
         
     def click_elemento_desde_elemento(self, elemento_padre:WebElement, metodo_busqueda:By|str, texto_busqueda:str) -> bool:
-        """ Clickea el elemento hijo """
+        """ Clickea el elemento hijo con estrategias de reintento """
         elemento = self.encontrar_elemento_desde_elemento(elemento_padre, metodo_busqueda, texto_busqueda, False)
         elemento = self.esperar_elemento_clickeable(metodo_busqueda, texto_busqueda, elemento_padre=elemento_padre)
         if not elemento: return False
         
+        return self._click_elemento_con_reintentos_desde_elemento(elemento, texto_busqueda)
+    
+    def _click_elemento_con_reintentos_desde_elemento(self, elemento: WebElement, texto_busqueda:str, max_intentos:int=3) -> bool:
+        """ Clickea el elemento hijo usando múltiples estrategias """
+        if not self._driver:
+            raise ValueError("El navegador no está abierto. Por favor, abre el navegador antes de hacer click en un elemento hijo.")
+        
+        for intento in range(max_intentos):
+            try:
+                if intento == 0:
+                    # Estrategia 1: Click directo
+                    self.mostrar(f"🔍 Intento {intento + 1}: Click directo en elemento hijo")
+                    self.__desplazar_elemento_a_vista(elemento)
+                    elemento.click()
+                    self.mostrar(f"✅ Click exitoso en elemento hijo {texto_busqueda}")
+                    return True
+                    
+                elif intento == 1:
+                    # Estrategia 2: JavaScript click
+                    self.mostrar(f"🔍 Intento {intento + 1}: JavaScript click en elemento hijo")
+                    self._driver.execute_script("arguments[0].click();", elemento)
+                    self.mostrar(f"✅ JavaScript click exitoso en elemento hijo {texto_busqueda}")
+                    return True
+                    
+                elif intento == 2:
+                    # Estrategia 3: ActionChains click
+                    self.mostrar(f"🔍 Intento {intento + 1}: ActionChains click en elemento hijo")
+                    from selenium.webdriver.common.action_chains import ActionChains
+                    actions = ActionChains(self._driver)
+                    actions.move_to_element(elemento).click().perform()
+                    self.mostrar(f"✅ ActionChains click exitoso en elemento hijo {texto_busqueda}")
+                    return True
+                    
+            except ElementClickInterceptedException:
+                self.mostrar(f"❌ Intento {intento + 1}: Elemento hijo {texto_busqueda} está siendo interceptado", True)
+                if intento < max_intentos - 1:
+                    self.mostrar(f"🔄 Reintentando con estrategia alternativa...")
+                    self.demora()
+                continue
+                
+            except Exception as e:
+                self.mostrar(f"❌ Intento {intento + 1}: Error al hacer click en elemento hijo {texto_busqueda}: {str(e)}", True)
+                if intento < max_intentos - 1:
+                    self.mostrar(f"🔄 Reintentando con estrategia alternativa...")
+                    self.demora()
+                continue
+        
+        self.mostrar(f"❌ No se pudo hacer click en elemento hijo {texto_busqueda} después de {max_intentos} intentos", True)
+        return False
+    
+    def click_elemento_en_iframe(self, iframe_selector:str, metodo_busqueda:By|str, texto_busqueda:str) -> bool:
+        """ 
+        Clickea un elemento dentro de un iframe específico 
+        
+        Args:
+            iframe_selector: Selector del iframe (ej: 'iframe[name="main"]' o '#iframe-id')
+            metodo_busqueda: Método para buscar el elemento dentro del iframe
+            texto_busqueda: Selector del elemento dentro del iframe
+        """
+        if not self._driver:
+            raise ValueError("El navegador no está abierto. Por favor, abre el navegador antes de buscar un elemento dentro de un iframe.")
+        
         try:
-            self.__desplazar_elemento_a_vista(elemento)
-            elemento.click()
-            return True
-        except ElementClickInterceptedException:
-            self.mostrar(f"El elemento {texto_busqueda} está siendo interceptado.")
+            # Guardar el contexto actual
+            contexto_original = self._driver.current_window_handle
+            
+            # Encontrar y cambiar al iframe
+            iframe = self.encontrar_elemento(By.CSS_SELECTOR, iframe_selector)
+            if not iframe:
+                self.mostrar(f"❌ No se encontró el iframe {iframe_selector}", True)
+                return False
+            
+            self.mostrar(f"🔄 Cambiando al iframe {iframe_selector}")
+            self._driver.switch_to.frame(iframe)
+            
+            # Intentar hacer click en el elemento dentro del iframe
+            resultado = self._click_elemento_con_reintentos(metodo_busqueda, texto_busqueda)
+            
+            # Volver al contexto original
+            self._driver.switch_to.default_content()
+            self.mostrar(f"🔄 Volviendo al contexto principal")
+            
+            return resultado
+            
+        except Exception as e:
+            # Asegurar que volvemos al contexto original en caso de error
+            try:
+                self._driver.switch_to.default_content()
+            except:
+                pass
+            
+            self.mostrar(f"❌ Error al hacer click en elemento dentro del iframe: {str(e)}", True)
             return False
         
     def click_button(self, texto_descripcion:str, metodo_busqueda:By|str, texto_busqueda:str) -> None:
@@ -566,7 +710,7 @@ class Chrome(Windows, Terminal):
                     continue
         return None, None
     
-    def click_elemento_en_iframe(self, metodo_busqueda, xpath_busqueda: str) -> bool:
+    def buscar_y_click_en_todos_los_iframes(self, metodo_busqueda, xpath_busqueda: str) -> bool:
         """
         Busca un elemento dentro de todos los iframes y hace click usando los métodos robustos de Chrome.
         Retorna True si encuentra y hace click exitosamente, False en caso contrario.
@@ -618,7 +762,7 @@ class Chrome(Windows, Terminal):
                     self._driver.switch_to.default_content()
             except:
                 pass
-            self.mostrar(f"❌ Error general en click_elemento_en_iframe: {str(e)}", True)
+            self.mostrar(f"❌ Error general en buscar_y_click_en_todos_los_iframes: {str(e)}", True)
             return False
     
     def click_elemento_directo(self, metodo_busqueda, xpath_busqueda: str) -> bool:
