@@ -198,43 +198,43 @@ class OB08(SAP):
             
             # Método 1: Buscar por title dentro de iframes
             self.mostrar("🎯 Método 1: Buscando por title 'Entradas nuevas (F5)'")
-            if self.click_elemento_en_iframe(By.XPATH, '//div[@title="Entradas nuevas (F5)"]'):
+            if self.buscar_y_click_en_todos_los_iframes(By.XPATH, '//div[@title="Entradas nuevas (F5)"]'):
                 self.mostrar("✅ Click exitoso por title")
                 return True
             
             # Método 2: Buscar por texto del span dentro de iframes
             self.mostrar("🎯 Método 2: Buscando por texto 'ntradas nuevas'")
-            if self.click_elemento_en_iframe(By.XPATH, '//span[contains(text(), "ntradas nuevas")]'):
+            if self.buscar_y_click_en_todos_los_iframes(By.XPATH, '//span[contains(text(), "ntradas nuevas")]'):
                 self.mostrar("✅ Click exitoso por texto")
                 return True
             
             # Método 3: Buscar por texto más específico
             self.mostrar("🎯 Método 3: Buscando por texto 'Entradas nuevas'")
-            if self.click_elemento_en_iframe(By.XPATH, '//span[contains(text(), "Entradas nuevas")]'):
+            if self.buscar_y_click_en_todos_los_iframes(By.XPATH, '//span[contains(text(), "Entradas nuevas")]'):
                 self.mostrar("✅ Click exitoso por texto específico")
                 return True
             
             # Método 4: Buscar por lsdata que contiene "Entradas nuevas"
             self.mostrar("🎯 Método 4: Buscando por lsdata")
-            if self.click_elemento_en_iframe(By.XPATH, '//div[contains(@lsdata, "Entradas nuevas")]'):
+            if self.buscar_y_click_en_todos_los_iframes(By.XPATH, '//div[contains(@lsdata, "Entradas nuevas")]'):
                 self.mostrar("✅ Click exitoso por lsdata")
                 return True
             
             # Método 5: Buscar por accesskey="E"
             self.mostrar("🎯 Método 5: Buscando por accesskey")
-            if self.click_elemento_en_iframe(By.XPATH, '//div[@accesskey="E"]'):
+            if self.buscar_y_click_en_todos_los_iframes(By.XPATH, '//div[@accesskey="E"]'):
                 self.mostrar("✅ Click exitoso por accesskey")
                 return True
                 
             # Método 6: Buscar botón con rol específico
             self.mostrar("🎯 Método 6: Buscando botón con rol")
-            if self.click_elemento_en_iframe(By.XPATH, '//div[@role="button" and contains(., "Entradas nuevas")]'):
+            if self.buscar_y_click_en_todos_los_iframes(By.XPATH, '//div[@role="button" and contains(., "Entradas nuevas")]'):
                 self.mostrar("✅ Click exitoso por rol de botón")
                 return True
             
             # Método 7: Buscar elemento clickeable que contenga el texto
             self.mostrar("🎯 Método 7: Buscando elemento clickeable con texto")
-            if self.click_elemento_en_iframe(By.XPATH, '//*[contains(text(), "Entradas nuevas") or contains(@title, "Entradas nuevas")]'):
+            if self.buscar_y_click_en_todos_los_iframes(By.XPATH, '//*[contains(text(), "Entradas nuevas") or contains(@title, "Entradas nuevas")]'):
                 self.mostrar("✅ Click exitoso por elemento clickeable")
                 return True
                 
